===========
Django Belt
===========

Simple package with some utilities for Django.

.. image:: https://travis-ci.org/marcosgabarda/django-belt.svg?branch=master
    :target: https://travis-ci.org/marcosgabarda/django-belt

.. image:: https://coveralls.io/repos/github/marcosgabarda/django-belt/badge.svg?branch=master
    :target: https://coveralls.io/github/marcosgabarda/django-belt?branch=master


Quick start
-----------

**1** Install using pip::

    pip install django-belt

**2** Add "belt" to your INSTALLED_APPS settings like this::

    INSTALLED_APPS += ('belt',)

